Facecore class
Entry point for the facecore plugin.
Use captureWithLiveness to launch the native liveness flow and obtain a captured frame after the user passes the configured challenges.
Constructors
- Facecore()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureWithLiveness(
{LivenessConfig config = const LivenessConfig()}) → Future< FaceCaptureResult?> - Launches the native liveness flow.
-
getPlatformVersion(
) → Future< String?> - Returns the host platform's reported version string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited