FacecorePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FacecorePlatform
Implementers

Constructors

FacecorePlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

captureWithLiveness(LivenessConfig config) Future<FaceCaptureResult?>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FacecorePlatform
getter/setter pair